#include "sprfile.h"

/*
    SPRFile.SoftBank
    ________________________________________________________________________

    The SoftBank class is intended for use with .spr files from
    SoftBank's port of the Neo*Geo game, Shin Samurai Spirits (aka SS2).
    This class facilitates the extraction and viewing of the sprites
    contained within that game.

    Please have respect for the art you extract.

    Copyright (C) 1997 / John Beppu
    Released under the GNU Public License
 
    ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::' */

struct SPRString {
    u32         len;
    u8          *data;
};

struct SPRite {
    u32         wd;
    u32         hi;
    u32         offset;
    SPRString   *strLUT;
};

class SoftBank : public SPRFile {

public:

    SoftBank (
        i8 *filename
        );
   ~SoftBank();

    u32 spriteWd (
        u32 spriteNDX
        ) const;
    u32 spriteHi (
        u32 spriteNDX
        ) const;
    u32 sizeOfHSI (
        u32 spriteNDX
        ) const;
    void makeHSI (
        u8 *dst,
        u32 spriteNDX
        ) const;
    void blt8bpp (
        u8 *dst,
        u32 pitch,
        u32 spriteNDX
        ) const;

private:

    u32         fileLEN;
    FILE        *file0;

    u32         kakaFactor;
    u32         bufferLEN;
    u8          *buffer;
    //          spriteQTY;      // protected SPRFile member
    SPRite      *spriteLUT;

    void checkSignature();
    u32 skipBullShit();
    void findSpriteQty(u32 ndx);
    void loadSpriteHeaders(u32 ndx);
    void loadSprites (
        i8 *filename,
        u32 ndx
        );

};
